<?php

/**
 * Handle all dashboard tasks
 */
class Emlg_Dashboard {
	/**
	 * The plugin's admin page hook
	 *
	 * @var string
	 */
	private $hook;

	/**
	 * Construct an instance
	 */
	public function __construct() {
		add_action( 'admin_menu', [ $this, 'admin_menu' ] );
		add_action( 'admin_enqueue_scripts', [ $this, 'enqueue_scripts' ] );
		add_filter( 'plugin_action_links_' . EMLG_BASE, array( $this, 'add_plugin_links' ) );
	}

	/**
	 * Add links to the plugins list
	 *
	 * @param array $links array of links for the plugins.
	 *
	 * @return array $links.
	 */
	public function add_plugin_links( $links ) {
		array_unshift( $links, '<a href="' . esc_url( admin_url( 'admin.php?page=emlg_main' ) ) . '">' . __( 'Settings', 'emlg-tfa' ) . '</a>' );

		return $links;
	}

	/**
	 * Enqueue admin scripts and styles
	 *
	 * @param string $hook current page hook.
	 *
	 * @return void
	 */
	public function enqueue_scripts( $hook ) {
		if ( $hook === $this->hook ) {
			// Enqueue only on our page.
			wp_enqueue_style( 'emlg/main', EMLG_URL . 'css/dashboard.css', [], EMLG_VERSION );
			wp_enqueue_style( 'wp-codemirror' );
			wp_enqueue_script( 'emlg/main', EMLG_URL . 'js/dashboard.js', [ 'jquery', 'wp-util' ], EMLG_VERSION, true );

			$codemirror_settings['codeEditor'] = wp_enqueue_code_editor( array( 'type' => 'htmlmixed' ) );
			$inline_js                         = 'window.emlg_options = ' . wp_json_encode( Emlg_Login::get_option() ) . ";\n";
			$inline_js                         .= 'window.emlg_codemirror_settings = ' . wp_json_encode( $codemirror_settings );

			wp_add_inline_script( 'emlg/main', $inline_js, 'before' );
		}
	}

	/**
	 * Add the admin page and menu element
	 *
	 * @return void
	 */
	public function admin_menu() {
		$this->hook = add_menu_page(
			__( 'EMLG TFA', 'emlg-tfa' ),
			__( 'EMLG TFA', 'emlg-tfa' ),
			'manage_options',
			'emlg_main',
			function() {
				require EMLG_PATH . 'views/admin-page.php';
			},
			'dashicons-shield-alt',
			76
		);
	}
}
