<?php

/**
 * Email handler
 */
class Emlg_Email {
	/**
	 * Recipient
	 *
	 * @var string
	 */
	public $to = '';

	/**
	 * Sender email
	 *
	 * @var string
	 */
	public $sender_email = '';

	/**
	 * Sender name
	 *
	 * @var string
	 */
	public $sender_name = '';

	/**
	 * Email subject
	 *
	 * @var string
	 */
	public $subject = '';

	/**
	 * Email body
	 *
	 * @var string
	 */
	public $message;

	/**
	 * Error message on 'wp_mail_failed'
	 *
	 * @var string
	 */
	private $wp_mail_error;

	public function __construct( $message = '' ) {
		$this->message = $message;
	}

	/**
	 * Partially obfuscate email address
	 *
	 * @param string $email the original email address.
	 *
	 * @return string
	 */
	public static function email_hint( $email ) {
		$exploded = explode( '@', $email );
		if ( count( $exploded ) !== 2 ) {
			return '';
		}

		return strlen( $exploded[0] ) <= 5
			? substr( $exploded[0], 0, 1 ) . str_repeat( '*', strlen( $exploded[0] ) - 1 ) . '@' . $exploded[1]
			:
			substr( $exploded[0], 0, 2 ) . str_repeat( '*', strlen( $exploded[0] ) - 4 ) . substr( $exploded[0], -2 ) . '@' . $exploded[1];
	}

	/**
	 * Change `wp_mail` content type to HTML
	 *
	 * @return string
	 */
	public function content_type() {
		return 'text/html';
	}

	/**
	 * Try to send the email
	 *
	 * @return bool|string true on success, an error message otherwise.
	 */
	public function send() {
		add_action( 'wp_mail_failed', [ $this, 'mail_failed' ] );
		add_filter( 'wp_mail_content_type', [ $this, 'content_type' ] );
		$success = wp_mail( $this->to, $this->subject, $this->message, [ 'From: ' . $this->sender_name . ' <' . $this->sender_email . '>' ] );
		remove_filter( 'wp_mail_content_type', [ $this, 'content_type' ] );
		remove_action( 'wp_mail_failed', [ $this, 'mail_failed' ] );

		if ( ! $success ) {
			$message = $this->wp_mail_error;

			if ( empty( $message ) ) {
				$message = __( 'WordPress could not send the email', 'emlg-tfa' );
			}

			$this->wp_mail_error = null;

			return $message;
		}

		if ( $this->wp_mail_error ) {
			$message             = $this->wp_mail_error;
			$this->wp_mail_error = null;

			return $message;
		}

		return true;
	}

	/**
	 * Email error handler hooked into "wp_mail_failed"
	 *
	 * @param WP_Error $error error returned by WordPress when attempting to send the email.
	 *
	 * @return void
	 */
	public function mail_failed( $error ) {
		if ( ! is_wp_error( $error ) ) {
			return;
		}
		$this->wp_mail_error = $error->get_error_message( 'wp_mail_failed' );
	}
}
